Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(367)

Unified Diff: ui/views/window/window_resources.h

Issue 10447053: Converts remainder of ui and chrome/browser/ui/views/frame to use ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/window/frame_background.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/window/window_resources.h
diff --git a/ui/views/window/window_resources.h b/ui/views/window/window_resources.h
index 14afc43b0b9d292bb3625d58afdabd48af765a8e..6243d2d8a59e9f6d789ea74638f90c9596c71d5d 100644
--- a/ui/views/window/window_resources.h
+++ b/ui/views/window/window_resources.h
@@ -6,25 +6,27 @@
#define UI_VIEWS_WINDOW_WINDOW_RESOURCES_H_
#pragma once
-class SkBitmap;
+namespace gfx {
+class ImageSkia;
+}
namespace views {
-typedef int FramePartBitmap;
+typedef int FramePartImage;
///////////////////////////////////////////////////////////////////////////////
// WindowResources
//
-// An interface implemented by an object providing bitmaps to render the
+// An interface implemented by an object providing images to render the
// contents of a window frame. The Window may swap in different
// implementations of this interface to render different modes. The definition
// of FramePartBitmap depends on the implementation.
//
class WindowResources {
public:
virtual ~WindowResources() {}
- virtual SkBitmap* GetPartBitmap(FramePartBitmap part) const = 0;
+ virtual gfx::ImageSkia* GetPartImage(FramePartImage part) const = 0;
};
} // namespace views
« no previous file with comments | « ui/views/window/frame_background.cc ('k') | no next file » | no next file with comments »
@@ -6,25 +6,27 @@
// contents of a window frame. The Window may swap in different
// implementations of this interface to render different modes. The definition
-// of FramePartBitmap depends on the implementation.
+// of FramePartImage depends on the implementation.
//
class WindowResources {

Powered by Google App Engine
This is Rietveld 408576698